#import "@preview/touying:0.5.3": *
#import themes.dewdrop: *
#import "latex-logo.typ": LaTeX
#import "tex-logo.typ": TeX
#import "@preview/numbly:0.1.0": numbly
#show: dewdrop-theme.with(
  aspect-ratio: "16-9",
  footer: self => self.info.institution,
  navigation: "mini-slides",
  config-info(
    title: [Séminaire #LaTeX],
    subtitle: [Ou LateK pour les intimes],
    author: [Aurélien],
    date: "20-11-2024",
    institution: [Crans],
  ),
)
#show ref: it => if it.element.func() != heading { it } else {
  let l = it.target // label
  let h = it.element // heading
  link(l, [#h.body])
}

#set heading(numbering: numbly("{1}.", default: "1.1"))

#title-slide()

#outline-slide()

= Introduction
#focus-slide[Introduction]
== #LaTeX c'est quoi?

- Logiciel *libre* de *composition de documents*.

- Langage balisé (comme en HTML).

C'est en réalité une version plus agréable de *#TeX*, qui est un logiciel libre crée par #underline[Donal~Knuth]~👴 en 1977.

== Pourquoi utiliser #LaTeX au lieu de Word par exemple?
- Permet de faire des documents de *haute qualité* en format *PDF*\ (des *articles*, des *slides*, des *CV*, etc ...).
- *Simple à utiliser* sans passer trop de temps à l'apprendre.
- *Indépendant de l'éditeur de texte*, facilitant le *partage*.
 - Très *complet* (on peut tout faire avec des packets, nottament en science)  
 - *bien documenté*(cf @installation).
- Philosophie *#underline[WYSIWYM]* (#text(style: "italic",[What you see is what you mean])): Comme Word ou autres, la mise en page est automatique, il y a juste a *s'occuper du fond*.
- Pratique pour travailler en *équipe* (cf @installation).
- C'est un logiciel *gratuit* et *libre* (pas comme Word (le mal 👿)).

= Installation<installation>
==
Pour *Windows/MacOS*: installation via MiKTeX #text(fill: blue,underline(link("https://miktex.org/download")[téléchargement])) (prends le moins de place possible sur le moment) ou TeXlive #text(fill: blue,underline(link("https://www.tug.org/texlive/acquire-netinstall.html")[téléchargement]))  (prends plus de place mais installe tout) \ \
Pour des distros *normales* de *Linux* (Ubuntu, Debian, Fedora, Mint, ...):\ ```sh sudo apt/dnf install texlive -full``` \ \
Les autres #text(fill: gradient.linear(..color.map.plasma), [bonne chance]) 😊. \ \

*Éditeur de texte et compilateur* : TeXStudio #text(fill: blue,underline(link("https://www.texstudio.org/#download")[téléchargement])) \ \
*En ligne* (pratique pour travailler en *équipe*): Overleaf #text(fill: blue,underline(link("https://www.overleaf.com/")))

= Stucture et syntaxe
#focus-slide[Structure et syntaxe]
== Caractères spéciaux
En #LaTeX, il y a des caractères qui se comportent différamment:

#table(
  columns: 3,
  inset: 5pt,
  align: center,
  table.header([*Symbole*], [*Signification*], [*Affichage*]),
  [\\],
  [début d'une commande, qui sont très présentes en #LaTeX.],
  [```LaTeX \textbackslash```],
  [\~],
  [espace un peu spécial, indique que les 2 mots sont  *inséparables* (par passage à la ligne).],
  [```tex \~```],
  [\$],
  [délimite le *mode math*],
  [```tex \$```],
  [^],
  [précède l'*exposant* d'un symbole dans le mode math.],
  [```tex \^```],
  [\_],
  [précède l'*indice* d'un symbole dans le mode math.],
  [```tex \_```],
  [%],
  [Commentaire],
  [```tex \%```],
  [{ et }],
  [début et fin d'un groupe de caractères (utilisé pour les arguments de commandes par exemple).],
  [```tex \{ et \}```],
  [\@],
  [C'est compliqué 😵‍💫 ...],
  [```tex @```]
)
== Document class et headers
La document class spécifie à #LaTeX le rendu qu'aura le document, cela se fait en début de document par la commande ```tex \documentclass{nom_classe}```, il en existe plein dont:

- `article` ou `report` pour la rédaction d'article ou compte-rendu (#text(style: "italic",[il y a quelques différences])).

-  `book` 📕 pour écrire des livres.

- `lettre` pour des lettres format français ou encore `memoir` pour des mémoires.

Il y a d'*autres informations* (optionelles) à renseigner *avant* de commencer le document:
- Le *titre* du document avec la commande ```tex \title{titre}```.
- L'*auteur* avec la commande ```tex \author{auteur}```.
- La *date* avec ```tex \date{date}```.
- L'*affiliation* de l'auteur avec ```tex \institute{truc}```.
== les packets
Les packets sont importés avant le début du document, avec la commande ```tex  \usepackage[option]{nom_package}```. \  Voici une liste des plus utiles:

- `inputenc` et `fontenc` avec comme option `utf8` et `T1` respectivement pour avoir tous les *caractères* et *accents* bien représentés.
- `babel` avec comme option n'importe quel langage 🌍 supporté.
- `ae` ou `lmodern` pour avoir des lettres plus *jolies* (à mettre avant `fontenc`).
- `graphicx` pour importer des *images* dans le document.
- `hyperref` pour faire des *références* à des sections ou mettre des liens.
- `amssymb` et `amsmath` pour les *maths* (symboles et environnements).
- `xcolor` pour mettre des #text(fill: gradient.linear(..color.map.rainbow), [couleurs]).
== Balises et commandes
#LaTeX est un langage balisé, tout ce qui sera affiché est compris entre ```tex \begin{document} et \end{document}``` (à mettre après ce qu'on a déjà vu). #LaTeX permet de segmenter le document avec les commandes ```tex \section{nom}, \subsection{nom}, \subsubsection{nom}```.\ \   Quelques~commandes utiles (certaines peuvent s'empiler):
- ```tex \maketitle```: affiche le titre, auteur, date, etc ...
- ```tex \tableofcontents```: affiche la table des matières.
- ```tex \newpage```: crée une nouvelle page.
- ```tex \textbf{Renzo Piano}```🎹: donne le résultat *Renzo Piano* dans le document.
- ```tex \textit{Pâtes}``` donne #text(style: "italic",[Pâtes]).
- ```tex \underline{Les liaisons dangereuses}``` donne #underline[Les liaisons dangereuses].
- ```tex \texttt{let inc n = n+1}``` donne `let inc n = n+1`.


= Macros et environnements
#focus-slide[Macros et environnements]
== Macros 
*Rappel*: #LaTeX est un ensemble de macros de #TeX et les commandes sont de la forme \ ```tex \commande[option 1, ..., option k]{arg 1,...., arg n}``` \ 
Exemple: ```tex \textcolor{red}{Word le mal!}``` donne: #text(fill : red,[Word le mal!]) \ \

On peut créer des commandes de cette forme avec (le $m^e$ arg est désigné par $\#m$): \
```tex \newcommand{\nom}[nb_d'arguments]{la définition}``` \
Par exemple, on peut créer la commande somme: \
  
```tex \newcommand{\somme}[3]{\sum_{#1=0}^{#2} #3}``` \
Ainsi, ```tex $\somme{i}{n}{i^{2}} = \frac{n(n+1)(2n+1)}{6}$ ``` donne dans le document: \
#align(center)[$ sum_(i=0)^n i^2 &= (n(n+1)(2n+1))/6$]
== Environnements
#LaTeX contient beaucoup d'environnements 🏞️ qui sont balisés . \ Par exemple ```tex \begin{document} ...\end{document}``` contient l'environnement du document. \ \ 
Voici quelques exemples d'environnements:
- math en inline (\$...\$ ou \\(...)\\, comme dans l'exemple de la somme) ou display(\$\$...\$\$ ou \\[...]\\):  \
  En display, l'exemple précédent s'affiche ainsi, détaché du texte:
  $ sum_(i=0)^n i^2 &= (n(n+1)(2n+1))/6 $ 
- Il y a aussi les environnements `itemize` (liste non numérotée), `enumerate` (numérotée), \ `center` (pour centrer du contenu), `tabular` (permet de faire un tableau) ou encore \ `frame` (qui représente une slide en `beamer`). \
 
 Par exemple, \ 
 ```tex \begin{itemize}```  \
 ```tex   \item truc            donne       ```     - truc     \
 ```tex   \item machin                      ``` - machin \    
 ```tex \end{itemize} ```  \
 \
 ```tex \includegraphics[option de taille]{linux-logo.png} ``` affiche: \
 #figure(
   image("Tux.png", width: 15%)
 )

= Documentation
==
Comme dit précédemment, #LaTeX est très bien documenté:\ \
- *Overleaf* propose des tutoriels et une documentation: #text(fill: blue,underline(link("https://www.overleaf.com/learn"))) \ \
- *StackExchange* (le meilleur site qui résout quasiment tous les problèmes 🙏): \ #text(fill: blue,underline(link("https://tex.stackexchange.com/"))) \ \
- *CTAN*, l'*encyclopédie des packets*: #text(fill: blue,underline(link("https://ctan.org/")))
\
- Pour ceux qui préfèrent les *gros livres*, le pdf du wikibook (écrit en #LaTeX): \
 #text(fill: blue,underline(link("https://upload.wikimedia.org/wikipedia/commons/2/2d/LaTeX.pdf")[Gros livre]))

= Résumé et exos
#focus-slide[Résumé]
== Résumé
Dans ce séminaire, nous avons vu que:

- #LaTeX est un logiciel *libre* et *gratuit* simple à utiliser et permettant de faire de jolis documents.

- Word est le #text(fill: red, [mal])! 👿

Plus *sérieusement*, nous avons vu: 
- que le *type de document* est donné par une *classe de document*.
- la *forme des commandes* et *comment en créer* de nouvelles.
- l'importation de *packets* (ensemble de commandes).
- que #LaTeX utilise essentiellement des *environnements*, qui ont des *balises de début et de fin*.
- les caractères *spéciaux* de #LaTeX.
#focus-slide[Cette présentation n'a pas été écrite en #LaTeX, mais en Typst, qui est une alternative à #LaTeX et le sujet d'un prochain séminaire pour ceux qui n'aiment pas trop les backslash.]
#focus-slide[Merci de votre attention !]
== Exercices

#underline[*Exo 1*]: Faire les macros suivantes: \
- Met en gras et souligne du texte. (```tex \boldunderline{text} ```$->$ #underline[*text*])
- (Package `halloweenmath`) Ce que vous voulez, qui prend 3 arguments et les utilise tous.
#underline[*Exo 2*]:Faire un début de présentation sur les hippopotames avec une slide titre, une slide table des matières et une slide contenant une photo d'hippopotame. \
#underline[*Exo 3*]: Formater le *texte* de la page wikipédia du batiment #text(style: "italic", [Bercy 2]) (fait par *Renzo Piano*) en \ #LaTeX en utilisant les packets et environnements appropriés (lien: #text(fill: blue,underline(link("https://fr.wikipedia.org/wiki/Bercy_2")[Bercy 2])) ) et en mettant en *gras* chaque occurence de *Renzo Piano* et en #text(style: "italic",[italique]) les batiments construits qui sont mentionés.(pas la peine de fait tout les liens hypertextes, seul 1 suffit, le reste est considéré comme du texte). \ 
#underline[*Exo 4*]: Écrire une lettre donnant un avis sur le séminaire et l'envoyer à #text(fill: blue, underline[aurelien\@crans.org]) seulement si vous voulez bien le faire.